==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/fragment-configuration-fields/ColorPickerField.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/fragment-configuration-fields/ColorPickerField", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/form', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../common/components/ColorPicker', '../../../plugins/page-design-options/hooks/useStyleBook', '../../../prop-types/index', './ColorPaletteField'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ColorPickerField = void 0;

    var _button = _interopRequireDefault(require("@frontend-taglib-clay$clayui/button"));

    var _form = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/form"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _ColorPicker = _interopRequireDefault(require("../../../common/components/ColorPicker"));

    var _useStyleBook2 = require("../../../plugins/page-design-options/hooks/useStyleBook");

    var _index = require("../../../prop-types/index");

    var _ColorPaletteField = require("./ColorPaletteField");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var COLOR_PICKER_TYPE = 'ColorPicker';

    var ColorPickerField = function ColorPickerField(_ref) {
      var _tokenValues$value;

      var field = _ref.field,
          _onValueSelect = _ref.onValueSelect,
          value = _ref.value;

      var _useStyleBook = (0, _useStyleBook2.useStyleBook)(),
          tokenValues = _useStyleBook.tokenValues;

      var _useState = (0, _react.useState)((_tokenValues$value = tokenValues[value]) === null || _tokenValues$value === void 0 ? void 0 : _tokenValues$value.value),
          _useState2 = _slicedToArray(_useState, 2),
          color = _useState2[0],
          setColor = _useState2[1];

      var colors = Object.values(tokenValues).filter(function (token) {
        return token.editorType === COLOR_PICKER_TYPE;
      }).map(function (token) {
        return {
          label: token.label,
          name: token.name,
          value: token.value
        };
      });

      if (!colors.length) {
        return _react["default"].createElement(_ColorPaletteField.ColorPaletteField, {
          field: field,
          onValueSelect: function onValueSelect(name, value) {
            var _value$rgbValue;

            return _onValueSelect(name, (_value$rgbValue = value === null || value === void 0 ? void 0 : value.rgbValue) !== null && _value$rgbValue !== void 0 ? _value$rgbValue : '');
          },
          value: value
        });
      }

      return _react["default"].createElement(_form["default"].Group, {
        small: true
      }, _react["default"].createElement("label", null, field.label), _react["default"].createElement(_form.ClayInput.Group, null, _react["default"].createElement(_form.ClayInput.GroupItem, {
        prepend: true,
        shrink: true
      }, _react["default"].createElement(_ColorPicker["default"], {
        colors: colors,
        onValueChange: function onValueChange(_ref2) {
          var name = _ref2.name,
              value = _ref2.value;
          setColor(value);

          _onValueSelect(field.name, name);
        },
        showHex: false,
        value: color
      })), _react["default"].createElement(_form.ClayInput.GroupItem, {
        append: true
      }, _react["default"].createElement(_form.ClayInput, {
        readOnly: true,
        value: tokenValues[value] ? tokenValues[value].label : Liferay.Language.get('default')
      }))), _react["default"].createElement(_button["default"], {
        className: "mt-2",
        displayType: "secondary",
        onClick: function onClick() {
          setColor('');

          _onValueSelect(field.name, '');
        }
      }, Liferay.Language.get('clear')));
    };

    exports.ColorPickerField = ColorPickerField;
    //# sourceMappingURL=ColorPickerField.js.map
  }
});
//# sourceMappingURL=ColorPickerField.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/fragment-configuration-fields/ColorPickerField.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/fragment-configuration-fields/ColorPickerField", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/form', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../common/components/ColorPicker', '../../../plugins/page-design-options/hooks/useStyleBook', '../../../prop-types/index', './ColorPaletteField'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ColorPickerField = void 0;

    var _button = _interopRequireDefault(require("@frontend-taglib-clay$clayui/button"));

    var _form = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/form"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _ColorPicker = _interopRequireDefault(require("../../../common/components/ColorPicker"));

    var _useStyleBook2 = require("../../../plugins/page-design-options/hooks/useStyleBook");

    var _index = require("../../../prop-types/index");

    var _ColorPaletteField = require("./ColorPaletteField");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var COLOR_PICKER_TYPE = 'ColorPicker';

    var ColorPickerField = function ColorPickerField(_ref) {
      var _tokenValues$value;

      var field = _ref.field,
          _onValueSelect = _ref.onValueSelect,
          value = _ref.value;

      var _useStyleBook = (0, _useStyleBook2.useStyleBook)(),
          tokenValues = _useStyleBook.tokenValues;

      var _useState = (0, _react.useState)((_tokenValues$value = tokenValues[value]) === null || _tokenValues$value === void 0 ? void 0 : _tokenValues$value.value),
          _useState2 = _slicedToArray(_useState, 2),
          color = _useState2[0],
          setColor = _useState2[1];

      var colors = Object.values(tokenValues).filter(function (token) {
        return token.editorType === COLOR_PICKER_TYPE;
      }).map(function (token) {
        return {
          label: token.label,
          name: token.name,
          value: token.value
        };
      });

      if (!colors.length) {
        return (/*#__PURE__*/_react.default.createElement(_ColorPaletteField.ColorPaletteField, {
            field: field,
            onValueSelect: function onValueSelect(name, value) {
              var _value$rgbValue;

              return _onValueSelect(name, (_value$rgbValue = value === null || value === void 0 ? void 0 : value.rgbValue) !== null && _value$rgbValue !== void 0 ? _value$rgbValue : '');
            },
            value: value
          })
        );
      }

      return (/*#__PURE__*/_react.default.createElement(_form.default.Group, {
          small: true
        }, /*#__PURE__*/_react.default.createElement("label", null, field.label), /*#__PURE__*/_react.default.createElement(_form.ClayInput.Group, null, /*#__PURE__*/_react.default.createElement(_form.ClayInput.GroupItem, {
          prepend: true,
          shrink: true
        }, /*#__PURE__*/_react.default.createElement(_ColorPicker.default, {
          colors: colors,
          onValueChange: function onValueChange(_ref2) {
            var name = _ref2.name,
                value = _ref2.value;
            setColor(value);

            _onValueSelect(field.name, name);
          },
          showHex: false,
          value: color
        })), /*#__PURE__*/_react.default.createElement(_form.ClayInput.GroupItem, {
          append: true
        }, /*#__PURE__*/_react.default.createElement(_form.ClayInput, {
          readOnly: true,
          value: tokenValues[value] ? tokenValues[value].label : Liferay.Language.get('default')
        }))), /*#__PURE__*/_react.default.createElement(_button.default, {
          className: "mt-2",
          displayType: "secondary",
          onClick: function onClick() {
            setColor('');

            _onValueSelect(field.name, '');
          }
        }, Liferay.Language.get('clear')))
      );
    };

    exports.ColorPickerField = ColorPickerField;
    //# sourceMappingURL=ColorPickerField.js.map
  }
});
//# sourceMappingURL=ColorPickerField.js.map
